package sgc.portal.cw.cw0802.persistence;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cw.cw0802.dto.CW08020001USearch;
import sgc.portal.cw.cw0802.model.CW08020001U;
import sgc.portal.cw.cw0802.model.CW08020002U;

import java.util.List;
import java.util.Map;

@Mapper
public interface CW08020001UMapper {
	
	//예약승인  조회
	List<EasyHashMap<String, Object>> selectZehrRomResrvtnStatusList(CW08020001USearch search);
	
	//예약이력  조회
	List<EasyHashMap<String, Object>> selectZehrRomHistrList(CW08020001USearch search);
	
	//예약승인반려 디스플레이
	void updateZehrRomResrvtn(CW08020002U cW08020002U);
	int insertZehrRomHistr(CW08020002U cW08020002U);
	void updateZehrRomDispl2(CW08020002U cW08020002U);
	void updateZehrRomDispl1(CW08020002U cW08020002U);
	
	String selectZehrRomResrvtnCdeptList(CW08020002U cW08020002U);
	String selectZehrRomResrvtnStatusInfoList(CW08020002U cW08020002U);
	List<EasyHashMap<String, Object>> selectUserEmailList(CW08020002U cW08020002U);
}
